Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(82)

Unified Diff: content/public/browser/web_contents_delegate.h

Issue 1181293003: Expand SecurityStyleChanged interfaces to include explanations (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: add CONTENT_EXPORT Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/web_contents_delegate.h
diff --git a/content/public/browser/web_contents_delegate.h b/content/public/browser/web_contents_delegate.h
index f191672c9d9c21b3a98b07dc9bbd5e967c8b3dec..34d39f779cd801cc983f6d449a9075a16d5746aa 100644
--- a/content/public/browser/web_contents_delegate.h
+++ b/content/public/browser/web_contents_delegate.h
@@ -47,6 +47,7 @@ struct DropData;
struct FileChooserParams;
struct NativeWebKeyboardEvent;
struct Referrer;
+struct SecurityStyleExplanations;
struct SSLStatus;
}
@@ -486,9 +487,13 @@ class CONTENT_EXPORT WebContentsDelegate {
// default behavior is suppressed.
virtual bool SaveFrame(const GURL& url, const Referrer& referrer);
- // Can be overridden by a delegate to return the security style of the given
- // |web_contents|. Returns SECURITY_STYLE_UNKNOWN if not overriden.
- virtual SecurityStyle GetSecurityStyle(WebContents* web_contents);
+ // Can be overridden by a delegate to return the security style of the
+ // given |web_contents|, populating |security_style_explanations| to
+ // explain why the SecurityStyle was downgraded. Returns
+ // SECURITY_STYLE_UNKNOWN if not overriden.
+ virtual SecurityStyle GetSecurityStyle(
+ WebContents* web_contents,
+ SecurityStyleExplanations* security_style_explanations);
protected:
virtual ~WebContentsDelegate();
« no previous file with comments | « content/public/browser/security_style_explanations.cc ('k') | content/public/browser/web_contents_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698